require  File.dirname(__FILE__) + '/../../../test_helper'

class Parlez::Admin::PostsControllerTest < ActionController::TestCase
  def test_get_index
    get :index

    assert assigns :posts
    assert_response :success
    assert_template :index
  end

  def test_get_edit_page
    p = Factory :post
    get :edit, :id => p.id
    assert_response :success
    assert_template :edit
    assert assigns :post
  end

  def test_create_new_post
    post :create, :parlez_post => post_attributes
    assert_response :redirect
    assert_redirected_to :action => :index
    assert_equal 'Post created!', flash[:notice]
  end

  def test_create_invalid_post
    post :create, :parlez_post => post_attributes.merge(:title => '')
    assert_response :success
    assert_template :new
    assert_equal 'Please correct the errors below.', flash[:error]
    assert_select '.field_with_errors', 1
  end

  def test_update_post
    p = Factory :post
    put :update, :id => p.id, :parlez_post => post_attributes
    assert_response :redirect
    assert_redirected_to :action => :index
    assert_equal 'Post saved!', flash[:notice]
  end

  def test_update_with_invalid
    p = Factory :post
    put :update, :id => p.id, :parlez_post => post_attributes.merge(:slug => '')
    assert_response :success
    assert_template :edit
    assert_equal 'Please correct the errors below.', flash[:error]
  end

  def test_update_non_existent
    put :update, :id => 'i-dont-exist', :parlez_post => post_attributes.merge(:slug => '')
    assert_response :redirect
    assert_redirected_to :action => :index
    assert_equal 'Post not found!', flash[:error]
  end

  def test_destroy
    p = Factory :post
    assert_difference 'Parlez::Post.count', -1 do
      delete :destroy, :id => p.id
      assert_response :redirect
      assert_redirected_to :action => :index
      assert_equal 'Post deleted.', flash[:notice]
    end
  end

  def test_destroy_non_existent
    p = Factory :post
    assert_no_difference 'Parlez::Post.count' do
      delete :destroy, :id => 'nope'
      assert_response :redirect
      assert_redirected_to :action => :index
      assert_equal 'Post not found!', flash[:error]
    end
  end

  def post_attributes
    { :title => 'title',
      :slug => 'title',
      :author => 'georges',
      "published_at(1i)" => "2010",
      "published_at(2i)" => "4",
      "published_at(3i)" => "20",
      "published_at(4i)" => "18",
      "published_at(5i)" => "09",
      :body => 'the body'
    }
  end
end
